# Sample Python code to stamp out Hamming Distance macro
# Kevin Angstadt
# angstadt {at} virginia.edu

from micronap.sdk import *

def main():
    # create workspace
    A = Anml()
    AN = A.CreateAutomataNetwork(anmlId='hamming_reads')
    
    # load the macro
    hamming = A.LoadAnmlMacro('hamming7_3.anml')
    
    # read in the DNA sequences
    f = open ('reads.txt', 'r')
    reads = f.readlines()
    f.close()
    
    for r in reads:
        r = r.strip()
        k = AN.AddMacroRef(hamming,anmlId=r)
        for i in range(len(r)):
            
            # get a handle to the parameter
            ref = hamming.GetMacroParamFromName('%'+str(i+1))
            
            # get a handle to sub the parameter
            sub = hamming.GetMacroParamSubstitutionHolder(ref)
            
            # set the value
            sub.ste.new_symbols = r[i]
            
            # write this out
            AN.SetMacroParamSubstitution(k,sub)
            
            # do the same for negation
            
            # get a handle to the parameter
            ref = hamming.GetMacroParamFromName('%n'+str(i+1))
            
            # get a handle to sub the parameter
            sub = hamming.GetMacroParamSubstitutionHolder(ref)
            
            # set the value
            sub.ste.new_symbols = "[^" + r[i] + "]"
            
            # write this out
            AN.SetMacroParamSubstitution(k,sub)
    
    # write out the file
    AN.ExportAnml('hamming_reads.anml')
    
if __name__ == '__main__':
    main()